Crate rustc_codegen_spirv_types

Crate rustc_codegen_spirv_types 

rustc_codegen_spirv-types

SPIR-V backend types shared between rustc_codegen_spirv and spirv-builder. Please refer to spirv-builder for more information.

Re-exports

pub use serde;
pub use serde_json;

Structs

CompileResult
SpirvTarget
A well-formed rust-gpu target.
TargetSpec

Enums

Capability
SPIR-V operand kind: Capability
ModuleResult
TargetError
TargetSpecVersion
Enum for different versions of target specs, to allow changing the target spec for different rust versions. The version listed in the enum is always the minimum version to require said target spec, with the newest version always at the top.

Constants

SPIRV_ARCH
SPIRV_TARGET_PREFIX
a

Functions

query_rustc_version