rustc_codegen_spirv-types
SPIR-V backend types shared between rustc_codegen_spirv and spirv-builder. Please refer to spirv-builder for more information.
Re-exports
pub use serde;pub use serde_json;
Structs
- Compile
Result - Spirv
Target - A well-formed rust-gpu target.
- Target
Spec
Enums
- Capability
- SPIR-V operand kind: Capability
- Module
Result - Target
Error - Target
Spec Version - Enum for different versions of target specs, to allow changing the target spec for different rust versions. The version listed in the enum is always the minimum version to require said target spec, with the newest version always at the top.